@@ -119,7 +119,8 @@ class Phonepatch:
 		self.sox_pars = "-t raw -c%d -w -s" %self.asterisk_channels
 		
 		# Festival (audio-to-speech generator) options
-		self.festival_isotolang = {"es": "spanish", "cy": "welsh"}
+		#self.festival_isotolang = {"es": "spanish", "cy": "welsh"}
+		self.festival_isotolang = {}
 			
 		# Configuration options
 		self.festival_indicator = "@"
